@@ -9,7 +9,7 @@ pub mod types;
 
 pub mod prelude {
 	#[cfg(ocvrs_has_module_core)]
-	pub use super::core::{MatConstIteratorTraitManual, MatTraitManual, MatxTrait, UMatTraitManual};
+	pub use super::core::{MatConstIteratorTraitManual, MatTraitConstManual, MatTraitManual, MatxTrait, UMatTraitConstManual};
 	#[cfg(all(ocvrs_has_module_core, ocvrs_opencv_branch_32))]
-	pub use super::core::MatSizeTraitManual;
+	pub use super::core::MatSizeTraitConstManual;
 }
