@@ -26,13 +26,16 @@ pub mod prelude {
 pub fn emdl1(signature1: &dyn core::ToInputArray, signature2: &dyn core::ToInputArray) -> Result<f32> {
 	input_array_arg!(signature1);
 	input_array_arg!(signature2);
-	unsafe { sys::cv_EMDL1_const__InputArrayR_const__InputArrayR(signature1.as_raw__InputArray(), signature2.as_raw__InputArray()) }.into_result()
+	let ret = unsafe { sys::cv_EMDL1_const__InputArrayR_const__InputArrayR(signature1.as_raw__InputArray(), signature2.as_raw__InputArray()) }.into_result()?;
+	Ok(ret)
 }
 
 /// Complete constructor
 #[inline]
 pub fn create_affine_transformer(full_affine: bool) -> Result<core::Ptr<dyn crate::shape::AffineTransformer>> {
-	unsafe { sys::cv_createAffineTransformer_bool(full_affine) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::AffineTransformer>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_createAffineTransformer_bool(full_affine) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::shape::AffineTransformer>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// ## C++ default parameters
@@ -40,7 +43,9 @@ pub fn create_affine_transformer(full_affine: bool) -> Result<core::Ptr<dyn crat
 /// * default_cost: 0.2f
 #[inline]
 pub fn create_chi_histogram_cost_extractor(n_dummies: i32, default_cost: f32) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-	unsafe { sys::cv_createChiHistogramCostExtractor_int_float(n_dummies, default_cost) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_createChiHistogramCostExtractor_int_float(n_dummies, default_cost) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// ## C++ default parameters
@@ -49,7 +54,9 @@ pub fn create_chi_histogram_cost_extractor(n_dummies: i32, default_cost: f32) ->
 /// * default_cost: 0.2f
 #[inline]
 pub fn create_emd_histogram_cost_extractor(flag: i32, n_dummies: i32, default_cost: f32) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-	unsafe { sys::cv_createEMDHistogramCostExtractor_int_int_float(flag, n_dummies, default_cost) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_createEMDHistogramCostExtractor_int_int_float(flag, n_dummies, default_cost) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// ## C++ default parameters
@@ -57,7 +64,9 @@ pub fn create_emd_histogram_cost_extractor(flag: i32, n_dummies: i32, default_co
 /// * default_cost: 0.2f
 #[inline]
 pub fn create_emdl1_histogram_cost_extractor(n_dummies: i32, default_cost: f32) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-	unsafe { sys::cv_createEMDL1HistogramCostExtractor_int_float(n_dummies, default_cost) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_createEMDL1HistogramCostExtractor_int_float(n_dummies, default_cost) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// ## C++ default parameters
@@ -65,7 +74,9 @@ pub fn create_emdl1_histogram_cost_extractor(n_dummies: i32, default_cost: f32)
 /// * rank_prop: 0.6f
 #[inline]
 pub fn create_hausdorff_distance_extractor(distance_flag: i32, rank_prop: f32) -> Result<core::Ptr<dyn crate::shape::HausdorffDistanceExtractor>> {
-	unsafe { sys::cv_createHausdorffDistanceExtractor_int_float(distance_flag, rank_prop) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::HausdorffDistanceExtractor>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_createHausdorffDistanceExtractor_int_float(distance_flag, rank_prop) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::shape::HausdorffDistanceExtractor>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// ## C++ default parameters
@@ -74,7 +85,9 @@ pub fn create_hausdorff_distance_extractor(distance_flag: i32, rank_prop: f32) -
 /// * default_cost: 0.2f
 #[inline]
 pub fn create_norm_histogram_cost_extractor(flag: i32, n_dummies: i32, default_cost: f32) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-	unsafe { sys::cv_createNormHistogramCostExtractor_int_int_float(flag, n_dummies, default_cost) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_createNormHistogramCostExtractor_int_int_float(flag, n_dummies, default_cost) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// ## C++ default parameters
@@ -87,7 +100,9 @@ pub fn create_norm_histogram_cost_extractor(flag: i32, n_dummies: i32, default_c
 /// * transformer: createThinPlateSplineShapeTransformer()
 #[inline]
 pub fn create_shape_context_distance_extractor(n_angular_bins: i32, n_radial_bins: i32, inner_radius: f32, outer_radius: f32, iterations: i32, comparer: &core::Ptr<dyn crate::shape::HistogramCostExtractor>, transformer: &core::Ptr<dyn crate::shape::ShapeTransformer>) -> Result<core::Ptr<dyn crate::shape::ShapeContextDistanceExtractor>> {
-	unsafe { sys::cv_createShapeContextDistanceExtractor_int_int_float_float_int_const_Ptr_HistogramCostExtractor_R_const_Ptr_ShapeTransformer_R(n_angular_bins, n_radial_bins, inner_radius, outer_radius, iterations, comparer.as_raw_PtrOfHistogramCostExtractor(), transformer.as_raw_PtrOfShapeTransformer()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::ShapeContextDistanceExtractor>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_createShapeContextDistanceExtractor_int_int_float_float_int_const_Ptr_HistogramCostExtractor_R_const_Ptr_ShapeTransformer_R(n_angular_bins, n_radial_bins, inner_radius, outer_radius, iterations, comparer.as_raw_PtrOfHistogramCostExtractor(), transformer.as_raw_PtrOfShapeTransformer()) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::shape::ShapeContextDistanceExtractor>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Complete constructor
@@ -96,7 +111,9 @@ pub fn create_shape_context_distance_extractor(n_angular_bins: i32, n_radial_bin
 /// * regularization_parameter: 0
 #[inline]
 pub fn create_thin_plate_spline_shape_transformer(regularization_parameter: f64) -> Result<core::Ptr<dyn crate::shape::ThinPlateSplineShapeTransformer>> {
-	unsafe { sys::cv_createThinPlateSplineShapeTransformer_double(regularization_parameter) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::ThinPlateSplineShapeTransformer>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_createThinPlateSplineShapeTransformer_double(regularization_parameter) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::shape::ThinPlateSplineShapeTransformer>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Wrapper class for the OpenCV Affine Transformation algorithm. :
@@ -105,7 +122,8 @@ pub trait AffineTransformerConst: crate::shape::ShapeTransformerConst {
 
 	#[inline]
 	fn get_full_affine(&self) -> Result<bool> {
-		unsafe { sys::cv_AffineTransformer_getFullAffine_const(self.as_raw_AffineTransformer()) }.into_result()
+		let ret = unsafe { sys::cv_AffineTransformer_getFullAffine_const(self.as_raw_AffineTransformer()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -115,7 +133,8 @@ pub trait AffineTransformer: crate::shape::AffineTransformerConst + crate::shape
 
 	#[inline]
 	fn set_full_affine(&mut self, full_affine: bool) -> Result<()> {
-		unsafe { sys::cv_AffineTransformer_setFullAffine_bool(self.as_raw_mut_AffineTransformer(), full_affine) }.into_result()
+		let ret = unsafe { sys::cv_AffineTransformer_setFullAffine_bool(self.as_raw_mut_AffineTransformer(), full_affine) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -137,7 +156,8 @@ pub trait EMDHistogramCostExtractorConst: crate::shape::HistogramCostExtractorCo
 
 	#[inline]
 	fn get_norm_flag(&self) -> Result<i32> {
-		unsafe { sys::cv_EMDHistogramCostExtractor_getNormFlag_const(self.as_raw_EMDHistogramCostExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_EMDHistogramCostExtractor_getNormFlag_const(self.as_raw_EMDHistogramCostExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -147,7 +167,8 @@ pub trait EMDHistogramCostExtractor: crate::shape::EMDHistogramCostExtractorCons
 
 	#[inline]
 	fn set_norm_flag(&mut self, flag: i32) -> Result<()> {
-		unsafe { sys::cv_EMDHistogramCostExtractor_setNormFlag_int(self.as_raw_mut_EMDHistogramCostExtractor(), flag) }.into_result()
+		let ret = unsafe { sys::cv_EMDHistogramCostExtractor_setNormFlag_int(self.as_raw_mut_EMDHistogramCostExtractor(), flag) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -175,12 +196,14 @@ pub trait HausdorffDistanceExtractorConst: crate::shape::ShapeDistanceExtractorC
 
 	#[inline]
 	fn get_distance_flag(&self) -> Result<i32> {
-		unsafe { sys::cv_HausdorffDistanceExtractor_getDistanceFlag_const(self.as_raw_HausdorffDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_HausdorffDistanceExtractor_getDistanceFlag_const(self.as_raw_HausdorffDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_rank_proportion(&self) -> Result<f32> {
-		unsafe { sys::cv_HausdorffDistanceExtractor_getRankProportion_const(self.as_raw_HausdorffDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_HausdorffDistanceExtractor_getRankProportion_const(self.as_raw_HausdorffDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -195,7 +218,8 @@ pub trait HausdorffDistanceExtractor: crate::shape::HausdorffDistanceExtractorCo
 	/// (NORM_L1, NORM_L2).
 	#[inline]
 	fn set_distance_flag(&mut self, distance_flag: i32) -> Result<()> {
-		unsafe { sys::cv_HausdorffDistanceExtractor_setDistanceFlag_int(self.as_raw_mut_HausdorffDistanceExtractor(), distance_flag) }.into_result()
+		let ret = unsafe { sys::cv_HausdorffDistanceExtractor_setDistanceFlag_int(self.as_raw_mut_HausdorffDistanceExtractor(), distance_flag) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// This method sets the rank proportion (or fractional value) that establish the Kth ranked value of
@@ -206,7 +230,8 @@ pub trait HausdorffDistanceExtractor: crate::shape::HausdorffDistanceExtractorCo
 	/// * rankProportion: fractional value (between 0 and 1).
 	#[inline]
 	fn set_rank_proportion(&mut self, rank_proportion: f32) -> Result<()> {
-		unsafe { sys::cv_HausdorffDistanceExtractor_setRankProportion_float(self.as_raw_mut_HausdorffDistanceExtractor(), rank_proportion) }.into_result()
+		let ret = unsafe { sys::cv_HausdorffDistanceExtractor_setRankProportion_float(self.as_raw_mut_HausdorffDistanceExtractor(), rank_proportion) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -217,12 +242,14 @@ pub trait HistogramCostExtractorConst: core::AlgorithmTraitConst {
 
 	#[inline]
 	fn get_n_dummies(&self) -> Result<i32> {
-		unsafe { sys::cv_HistogramCostExtractor_getNDummies_const(self.as_raw_HistogramCostExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_HistogramCostExtractor_getNDummies_const(self.as_raw_HistogramCostExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_default_cost(&self) -> Result<f32> {
-		unsafe { sys::cv_HistogramCostExtractor_getDefaultCost_const(self.as_raw_HistogramCostExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_HistogramCostExtractor_getDefaultCost_const(self.as_raw_HistogramCostExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -235,17 +262,20 @@ pub trait HistogramCostExtractor: core::AlgorithmTrait + crate::shape::Histogram
 		input_array_arg!(descriptors1);
 		input_array_arg!(descriptors2);
 		output_array_arg!(cost_matrix);
-		unsafe { sys::cv_HistogramCostExtractor_buildCostMatrix_const__InputArrayR_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_HistogramCostExtractor(), descriptors1.as_raw__InputArray(), descriptors2.as_raw__InputArray(), cost_matrix.as_raw__OutputArray()) }.into_result()
+		let ret = unsafe { sys::cv_HistogramCostExtractor_buildCostMatrix_const__InputArrayR_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_HistogramCostExtractor(), descriptors1.as_raw__InputArray(), descriptors2.as_raw__InputArray(), cost_matrix.as_raw__OutputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_n_dummies(&mut self, n_dummies: i32) -> Result<()> {
-		unsafe { sys::cv_HistogramCostExtractor_setNDummies_int(self.as_raw_mut_HistogramCostExtractor(), n_dummies) }.into_result()
+		let ret = unsafe { sys::cv_HistogramCostExtractor_setNDummies_int(self.as_raw_mut_HistogramCostExtractor(), n_dummies) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_default_cost(&mut self, default_cost: f32) -> Result<()> {
-		unsafe { sys::cv_HistogramCostExtractor_setDefaultCost_float(self.as_raw_mut_HistogramCostExtractor(), default_cost) }.into_result()
+		let ret = unsafe { sys::cv_HistogramCostExtractor_setDefaultCost_float(self.as_raw_mut_HistogramCostExtractor(), default_cost) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -256,7 +286,8 @@ pub trait NormHistogramCostExtractorConst: crate::shape::HistogramCostExtractorC
 
 	#[inline]
 	fn get_norm_flag(&self) -> Result<i32> {
-		unsafe { sys::cv_NormHistogramCostExtractor_getNormFlag_const(self.as_raw_NormHistogramCostExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_NormHistogramCostExtractor_getNormFlag_const(self.as_raw_NormHistogramCostExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -266,7 +297,8 @@ pub trait NormHistogramCostExtractor: crate::shape::HistogramCostExtractor + cra
 
 	#[inline]
 	fn set_norm_flag(&mut self, flag: i32) -> Result<()> {
-		unsafe { sys::cv_NormHistogramCostExtractor_setNormFlag_int(self.as_raw_mut_NormHistogramCostExtractor(), flag) }.into_result()
+		let ret = unsafe { sys::cv_NormHistogramCostExtractor_setNormFlag_int(self.as_raw_mut_NormHistogramCostExtractor(), flag) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -284,69 +316,84 @@ pub trait ShapeContextDistanceExtractorConst: crate::shape::ShapeDistanceExtract
 
 	#[inline]
 	fn get_angular_bins(&self) -> Result<i32> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getAngularBins_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getAngularBins_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_radial_bins(&self) -> Result<i32> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getRadialBins_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getRadialBins_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_inner_radius(&self) -> Result<f32> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getInnerRadius_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getInnerRadius_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_outer_radius(&self) -> Result<f32> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getOuterRadius_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getOuterRadius_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_rotation_invariant(&self) -> Result<bool> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getRotationInvariant_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getRotationInvariant_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_shape_context_weight(&self) -> Result<f32> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getShapeContextWeight_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getShapeContextWeight_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_image_appearance_weight(&self) -> Result<f32> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getImageAppearanceWeight_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getImageAppearanceWeight_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_bending_energy_weight(&self) -> Result<f32> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getBendingEnergyWeight_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getBendingEnergyWeight_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_images(&self, image1: &mut dyn core::ToOutputArray, image2: &mut dyn core::ToOutputArray) -> Result<()> {
 		output_array_arg!(image1);
 		output_array_arg!(image2);
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getImages_const_const__OutputArrayR_const__OutputArrayR(self.as_raw_ShapeContextDistanceExtractor(), image1.as_raw__OutputArray(), image2.as_raw__OutputArray()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getImages_const_const__OutputArrayR_const__OutputArrayR(self.as_raw_ShapeContextDistanceExtractor(), image1.as_raw__OutputArray(), image2.as_raw__OutputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_iterations(&self) -> Result<i32> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getIterations_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getIterations_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_cost_extractor(&self) -> Result<core::Ptr<dyn crate::shape::HistogramCostExtractor>> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getCostExtractor_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getCostExtractor_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		let ret = unsafe { core::Ptr::<dyn crate::shape::HistogramCostExtractor>::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_std_dev(&self) -> Result<f32> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getStdDev_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getStdDev_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_transform_algorithm(&self) -> Result<core::Ptr<dyn crate::shape::ShapeTransformer>> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_getTransformAlgorithm_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::shape::ShapeTransformer>::opencv_from_extern(r) } )
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_getTransformAlgorithm_const(self.as_raw_ShapeContextDistanceExtractor()) }.into_result()?;
+		let ret = unsafe { core::Ptr::<dyn crate::shape::ShapeTransformer>::opencv_from_extern(ret) };
+		Ok(ret)
 	}
 	
 }
@@ -361,7 +408,8 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * nAngularBins: The number of angular bins in the shape context descriptor.
 	#[inline]
 	fn set_angular_bins(&mut self, n_angular_bins: i32) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setAngularBins_int(self.as_raw_mut_ShapeContextDistanceExtractor(), n_angular_bins) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setAngularBins_int(self.as_raw_mut_ShapeContextDistanceExtractor(), n_angular_bins) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Establish the number of radial bins for the Shape Context Descriptor used in the shape matching
@@ -371,7 +419,8 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * nRadialBins: The number of radial bins in the shape context descriptor.
 	#[inline]
 	fn set_radial_bins(&mut self, n_radial_bins: i32) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setRadialBins_int(self.as_raw_mut_ShapeContextDistanceExtractor(), n_radial_bins) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setRadialBins_int(self.as_raw_mut_ShapeContextDistanceExtractor(), n_radial_bins) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set the inner radius of the shape context descriptor.
@@ -380,7 +429,8 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * innerRadius: The value of the inner radius.
 	#[inline]
 	fn set_inner_radius(&mut self, inner_radius: f32) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setInnerRadius_float(self.as_raw_mut_ShapeContextDistanceExtractor(), inner_radius) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setInnerRadius_float(self.as_raw_mut_ShapeContextDistanceExtractor(), inner_radius) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set the outer radius of the shape context descriptor.
@@ -389,12 +439,14 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * outerRadius: The value of the outer radius.
 	#[inline]
 	fn set_outer_radius(&mut self, outer_radius: f32) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setOuterRadius_float(self.as_raw_mut_ShapeContextDistanceExtractor(), outer_radius) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setOuterRadius_float(self.as_raw_mut_ShapeContextDistanceExtractor(), outer_radius) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_rotation_invariant(&mut self, rotation_invariant: bool) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setRotationInvariant_bool(self.as_raw_mut_ShapeContextDistanceExtractor(), rotation_invariant) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setRotationInvariant_bool(self.as_raw_mut_ShapeContextDistanceExtractor(), rotation_invariant) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set the weight of the shape context distance in the final value of the shape distance. The shape
@@ -406,7 +458,8 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * shapeContextWeight: The weight of the shape context distance in the final distance value.
 	#[inline]
 	fn set_shape_context_weight(&mut self, shape_context_weight: f32) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setShapeContextWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), shape_context_weight) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setShapeContextWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), shape_context_weight) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set the weight of the Image Appearance cost in the final value of the shape distance. The image
@@ -420,7 +473,8 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * imageAppearanceWeight: The weight of the appearance cost in the final distance value.
 	#[inline]
 	fn set_image_appearance_weight(&mut self, image_appearance_weight: f32) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setImageAppearanceWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), image_appearance_weight) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setImageAppearanceWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), image_appearance_weight) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set the weight of the Bending Energy in the final value of the shape distance. The bending energy
@@ -432,7 +486,8 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * bendingEnergyWeight: The weight of the Bending Energy in the final distance value.
 	#[inline]
 	fn set_bending_energy_weight(&mut self, bending_energy_weight: f32) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setBendingEnergyWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), bending_energy_weight) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setBendingEnergyWeight_float(self.as_raw_mut_ShapeContextDistanceExtractor(), bending_energy_weight) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set the images that correspond to each shape. This images are used in the calculation of the Image
@@ -445,12 +500,14 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	fn set_images(&mut self, image1: &dyn core::ToInputArray, image2: &dyn core::ToInputArray) -> Result<()> {
 		input_array_arg!(image1);
 		input_array_arg!(image2);
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setImages_const__InputArrayR_const__InputArrayR(self.as_raw_mut_ShapeContextDistanceExtractor(), image1.as_raw__InputArray(), image2.as_raw__InputArray()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setImages_const__InputArrayR_const__InputArrayR(self.as_raw_mut_ShapeContextDistanceExtractor(), image1.as_raw__InputArray(), image2.as_raw__InputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_iterations(&mut self, iterations: i32) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setIterations_int(self.as_raw_mut_ShapeContextDistanceExtractor(), iterations) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setIterations_int(self.as_raw_mut_ShapeContextDistanceExtractor(), iterations) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set the algorithm used for building the shape context descriptor cost matrix.
@@ -460,7 +517,8 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// matrix between descriptors.
 	#[inline]
 	fn set_cost_extractor(&mut self, mut comparer: core::Ptr<dyn crate::shape::HistogramCostExtractor>) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setCostExtractor_Ptr_HistogramCostExtractor_(self.as_raw_mut_ShapeContextDistanceExtractor(), comparer.as_raw_mut_PtrOfHistogramCostExtractor()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setCostExtractor_Ptr_HistogramCostExtractor_(self.as_raw_mut_ShapeContextDistanceExtractor(), comparer.as_raw_mut_PtrOfHistogramCostExtractor()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set the value of the standard deviation for the Gaussian window for the image appearance cost.
@@ -469,7 +527,8 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// * sigma: Standard Deviation.
 	#[inline]
 	fn set_std_dev(&mut self, sigma: f32) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setStdDev_float(self.as_raw_mut_ShapeContextDistanceExtractor(), sigma) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setStdDev_float(self.as_raw_mut_ShapeContextDistanceExtractor(), sigma) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Set the algorithm used for aligning the shapes.
@@ -479,7 +538,8 @@ pub trait ShapeContextDistanceExtractor: crate::shape::ShapeContextDistanceExtra
 	/// transformation.
 	#[inline]
 	fn set_transform_algorithm(&mut self, mut transformer: core::Ptr<dyn crate::shape::ShapeTransformer>) -> Result<()> {
-		unsafe { sys::cv_ShapeContextDistanceExtractor_setTransformAlgorithm_Ptr_ShapeTransformer_(self.as_raw_mut_ShapeContextDistanceExtractor(), transformer.as_raw_mut_PtrOfShapeTransformer()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeContextDistanceExtractor_setTransformAlgorithm_Ptr_ShapeTransformer_(self.as_raw_mut_ShapeContextDistanceExtractor(), transformer.as_raw_mut_PtrOfShapeTransformer()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -505,7 +565,8 @@ pub trait ShapeDistanceExtractor: core::AlgorithmTrait + crate::shape::ShapeDist
 	fn compute_distance(&mut self, contour1: &dyn core::ToInputArray, contour2: &dyn core::ToInputArray) -> Result<f32> {
 		input_array_arg!(contour1);
 		input_array_arg!(contour2);
-		unsafe { sys::cv_ShapeDistanceExtractor_computeDistance_const__InputArrayR_const__InputArrayR(self.as_raw_mut_ShapeDistanceExtractor(), contour1.as_raw__InputArray(), contour2.as_raw__InputArray()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeDistanceExtractor_computeDistance_const__InputArrayR_const__InputArrayR(self.as_raw_mut_ShapeDistanceExtractor(), contour1.as_raw__InputArray(), contour2.as_raw__InputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -531,7 +592,8 @@ pub trait ShapeTransformerConst: core::AlgorithmTraitConst {
 	fn warp_image(&self, transforming_image: &dyn core::ToInputArray, output: &mut dyn core::ToOutputArray, flags: i32, border_mode: i32, border_value: core::Scalar) -> Result<()> {
 		input_array_arg!(transforming_image);
 		output_array_arg!(output);
-		unsafe { sys::cv_ShapeTransformer_warpImage_const_const__InputArrayR_const__OutputArrayR_int_int_const_ScalarR(self.as_raw_ShapeTransformer(), transforming_image.as_raw__InputArray(), output.as_raw__OutputArray(), flags, border_mode, &border_value) }.into_result()
+		let ret = unsafe { sys::cv_ShapeTransformer_warpImage_const_const__InputArrayR_const__OutputArrayR_int_int_const_ScalarR(self.as_raw_ShapeTransformer(), transforming_image.as_raw__InputArray(), output.as_raw__OutputArray(), flags, border_mode, &border_value) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -549,7 +611,8 @@ pub trait ShapeTransformer: core::AlgorithmTrait + crate::shape::ShapeTransforme
 	fn estimate_transformation(&mut self, transforming_shape: &dyn core::ToInputArray, target_shape: &dyn core::ToInputArray, matches: &mut core::Vector<core::DMatch>) -> Result<()> {
 		input_array_arg!(transforming_shape);
 		input_array_arg!(target_shape);
-		unsafe { sys::cv_ShapeTransformer_estimateTransformation_const__InputArrayR_const__InputArrayR_vector_DMatch_R(self.as_raw_mut_ShapeTransformer(), transforming_shape.as_raw__InputArray(), target_shape.as_raw__InputArray(), matches.as_raw_mut_VectorOfDMatch()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeTransformer_estimateTransformation_const__InputArrayR_const__InputArrayR_vector_DMatch_R(self.as_raw_mut_ShapeTransformer(), transforming_shape.as_raw__InputArray(), target_shape.as_raw__InputArray(), matches.as_raw_mut_VectorOfDMatch()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Apply a transformation, given a pre-estimated transformation parameters.
@@ -564,7 +627,8 @@ pub trait ShapeTransformer: core::AlgorithmTrait + crate::shape::ShapeTransforme
 	fn apply_transformation(&mut self, input: &dyn core::ToInputArray, output: &mut dyn core::ToOutputArray) -> Result<f32> {
 		input_array_arg!(input);
 		output_array_arg!(output);
-		unsafe { sys::cv_ShapeTransformer_applyTransformation_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_ShapeTransformer(), input.as_raw__InputArray(), output.as_raw__OutputArray()) }.into_result()
+		let ret = unsafe { sys::cv_ShapeTransformer_applyTransformation_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_ShapeTransformer(), input.as_raw__InputArray(), output.as_raw__OutputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -578,7 +642,8 @@ pub trait ThinPlateSplineShapeTransformerConst: crate::shape::ShapeTransformerCo
 
 	#[inline]
 	fn get_regularization_parameter(&self) -> Result<f64> {
-		unsafe { sys::cv_ThinPlateSplineShapeTransformer_getRegularizationParameter_const(self.as_raw_ThinPlateSplineShapeTransformer()) }.into_result()
+		let ret = unsafe { sys::cv_ThinPlateSplineShapeTransformer_getRegularizationParameter_const(self.as_raw_ThinPlateSplineShapeTransformer()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -593,7 +658,8 @@ pub trait ThinPlateSplineShapeTransformer: crate::shape::ShapeTransformer + crat
 	/// * beta: value of the regularization parameter.
 	#[inline]
 	fn set_regularization_parameter(&mut self, beta: f64) -> Result<()> {
-		unsafe { sys::cv_ThinPlateSplineShapeTransformer_setRegularizationParameter_double(self.as_raw_mut_ThinPlateSplineShapeTransformer(), beta) }.into_result()
+		let ret = unsafe { sys::cv_ThinPlateSplineShapeTransformer_setRegularizationParameter_double(self.as_raw_mut_ThinPlateSplineShapeTransformer(), beta) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
