@@ -118,7 +118,8 @@ opencv_type_enum! { crate::xphoto::TransformTypes }
 pub fn apply_channel_gains(src: &dyn core::ToInputArray, dst: &mut dyn core::ToOutputArray, gain_b: f32, gain_g: f32, gain_r: f32) -> Result<()> {
 	input_array_arg!(src);
 	output_array_arg!(dst);
-	unsafe { sys::cv_xphoto_applyChannelGains_const__InputArrayR_const__OutputArrayR_float_float_float(src.as_raw__InputArray(), dst.as_raw__OutputArray(), gain_b, gain_g, gain_r) }.into_result()
+	let ret = unsafe { sys::cv_xphoto_applyChannelGains_const__InputArrayR_const__OutputArrayR_float_float_float(src.as_raw__InputArray(), dst.as_raw__OutputArray(), gain_b, gain_g, gain_r) }.into_result()?;
+	Ok(ret)
 }
 
 /// Performs image denoising using the Block-Matching and 3D-filtering algorithm
@@ -175,7 +176,8 @@ pub fn bm3d_denoising(src: &dyn core::ToInputArray, dst_step1: &mut dyn core::To
 	input_array_arg!(src);
 	input_output_array_arg!(dst_step1);
 	output_array_arg!(dst_step2);
-	unsafe { sys::cv_xphoto_bm3dDenoising_const__InputArrayR_const__InputOutputArrayR_const__OutputArrayR_float_int_int_int_int_int_int_float_int_int_int(src.as_raw__InputArray(), dst_step1.as_raw__InputOutputArray(), dst_step2.as_raw__OutputArray(), h, template_window_size, search_window_size, block_matching_step1, block_matching_step2, group_size, sliding_step, beta, norm_type, step, transform_type) }.into_result()
+	let ret = unsafe { sys::cv_xphoto_bm3dDenoising_const__InputArrayR_const__InputOutputArrayR_const__OutputArrayR_float_int_int_int_int_int_int_float_int_int_int(src.as_raw__InputArray(), dst_step1.as_raw__InputOutputArray(), dst_step2.as_raw__OutputArray(), h, template_window_size, search_window_size, block_matching_step1, block_matching_step2, group_size, sliding_step, beta, norm_type, step, transform_type) }.into_result()?;
+	Ok(ret)
 }
 
 /// Performs image denoising using the Block-Matching and 3D-filtering algorithm
@@ -231,13 +233,16 @@ pub fn bm3d_denoising(src: &dyn core::ToInputArray, dst_step1: &mut dyn core::To
 pub fn bm3d_denoising_1(src: &dyn core::ToInputArray, dst: &mut dyn core::ToOutputArray, h: f32, template_window_size: i32, search_window_size: i32, block_matching_step1: i32, block_matching_step2: i32, group_size: i32, sliding_step: i32, beta: f32, norm_type: i32, step: i32, transform_type: i32) -> Result<()> {
 	input_array_arg!(src);
 	output_array_arg!(dst);
-	unsafe { sys::cv_xphoto_bm3dDenoising_const__InputArrayR_const__OutputArrayR_float_int_int_int_int_int_int_float_int_int_int(src.as_raw__InputArray(), dst.as_raw__OutputArray(), h, template_window_size, search_window_size, block_matching_step1, block_matching_step2, group_size, sliding_step, beta, norm_type, step, transform_type) }.into_result()
+	let ret = unsafe { sys::cv_xphoto_bm3dDenoising_const__InputArrayR_const__OutputArrayR_float_int_int_int_int_int_int_float_int_int_int(src.as_raw__InputArray(), dst.as_raw__OutputArray(), h, template_window_size, search_window_size, block_matching_step1, block_matching_step2, group_size, sliding_step, beta, norm_type, step, transform_type) }.into_result()?;
+	Ok(ret)
 }
 
 /// Creates an instance of GrayworldWB
 #[inline]
 pub fn create_grayworld_wb() -> Result<core::Ptr<dyn crate::xphoto::GrayworldWB>> {
-	unsafe { sys::cv_xphoto_createGrayworldWB() }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::xphoto::GrayworldWB>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_xphoto_createGrayworldWB() }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::xphoto::GrayworldWB>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates an instance of LearningBasedWB
@@ -250,13 +255,17 @@ pub fn create_grayworld_wb() -> Result<core::Ptr<dyn crate::xphoto::GrayworldWB>
 #[inline]
 pub fn create_learning_based_wb(path_to_model: &str) -> Result<core::Ptr<dyn crate::xphoto::LearningBasedWB>> {
 	extern_container_arg!(path_to_model);
-	unsafe { sys::cv_xphoto_createLearningBasedWB_const_StringR(path_to_model.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::xphoto::LearningBasedWB>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_xphoto_createLearningBasedWB_const_StringR(path_to_model.opencv_as_extern()) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::xphoto::LearningBasedWB>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates an instance of SimpleWB
 #[inline]
 pub fn create_simple_wb() -> Result<core::Ptr<dyn crate::xphoto::SimpleWB>> {
-	unsafe { sys::cv_xphoto_createSimpleWB() }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::xphoto::SimpleWB>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_xphoto_createSimpleWB() }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::xphoto::SimpleWB>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates TonemapDurand object
@@ -279,7 +288,9 @@ pub fn create_simple_wb() -> Result<core::Ptr<dyn crate::xphoto::SimpleWB>> {
 /// * sigma_space: 2.0f
 #[inline]
 pub fn create_tonemap_durand(gamma: f32, contrast: f32, saturation: f32, sigma_color: f32, sigma_space: f32) -> Result<core::Ptr<dyn crate::xphoto::TonemapDurand>> {
-	unsafe { sys::cv_xphoto_createTonemapDurand_float_float_float_float_float(gamma, contrast, saturation, sigma_color, sigma_space) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::xphoto::TonemapDurand>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_xphoto_createTonemapDurand_float_float_float_float_float(gamma, contrast, saturation, sigma_color, sigma_space) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::xphoto::TonemapDurand>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// The function implements simple dct-based denoising
@@ -297,7 +308,8 @@ pub fn create_tonemap_durand(gamma: f32, contrast: f32, saturation: f32, sigma_c
 /// * psize: 16
 #[inline]
 pub fn dct_denoising(src: &core::Mat, dst: &mut core::Mat, sigma: f64, psize: i32) -> Result<()> {
-	unsafe { sys::cv_xphoto_dctDenoising_const_MatR_MatR_const_double_const_int(src.as_raw_Mat(), dst.as_raw_mut_Mat(), sigma, psize) }.into_result()
+	let ret = unsafe { sys::cv_xphoto_dctDenoising_const_MatR_MatR_const_double_const_int(src.as_raw_Mat(), dst.as_raw_mut_Mat(), sigma, psize) }.into_result()?;
+	Ok(ret)
 }
 
 /// The function implements different single-image inpainting algorithms.
@@ -317,7 +329,8 @@ pub fn dct_denoising(src: &core::Mat, dst: &mut core::Mat, sigma: f64, psize: i3
 /// * algorithmType: see xphoto::InpaintTypes
 #[inline]
 pub fn inpaint(src: &core::Mat, mask: &core::Mat, dst: &mut core::Mat, algorithm_type: i32) -> Result<()> {
-	unsafe { sys::cv_xphoto_inpaint_const_MatR_const_MatR_MatR_const_int(src.as_raw_Mat(), mask.as_raw_Mat(), dst.as_raw_mut_Mat(), algorithm_type) }.into_result()
+	let ret = unsafe { sys::cv_xphoto_inpaint_const_MatR_const_MatR_MatR_const_int(src.as_raw_Mat(), mask.as_raw_Mat(), dst.as_raw_mut_Mat(), algorithm_type) }.into_result()?;
+	Ok(ret)
 }
 
 /// oilPainting
@@ -331,7 +344,8 @@ pub fn inpaint(src: &core::Mat, mask: &core::Mat, dst: &mut core::Mat, algorithm
 pub fn oil_painting_1(src: &dyn core::ToInputArray, dst: &mut dyn core::ToOutputArray, size: i32, dyn_ratio: i32) -> Result<()> {
 	input_array_arg!(src);
 	output_array_arg!(dst);
-	unsafe { sys::cv_xphoto_oilPainting_const__InputArrayR_const__OutputArrayR_int_int(src.as_raw__InputArray(), dst.as_raw__OutputArray(), size, dyn_ratio) }.into_result()
+	let ret = unsafe { sys::cv_xphoto_oilPainting_const__InputArrayR_const__OutputArrayR_int_int(src.as_raw__InputArray(), dst.as_raw__OutputArray(), size, dyn_ratio) }.into_result()?;
+	Ok(ret)
 }
 
 /// oilPainting
@@ -346,7 +360,8 @@ pub fn oil_painting_1(src: &dyn core::ToInputArray, dst: &mut dyn core::ToOutput
 pub fn oil_painting(src: &dyn core::ToInputArray, dst: &mut dyn core::ToOutputArray, size: i32, dyn_ratio: i32, code: i32) -> Result<()> {
 	input_array_arg!(src);
 	output_array_arg!(dst);
-	unsafe { sys::cv_xphoto_oilPainting_const__InputArrayR_const__OutputArrayR_int_int_int(src.as_raw__InputArray(), dst.as_raw__OutputArray(), size, dyn_ratio, code) }.into_result()
+	let ret = unsafe { sys::cv_xphoto_oilPainting_const__InputArrayR_const__OutputArrayR_int_int_int(src.as_raw__InputArray(), dst.as_raw__OutputArray(), size, dyn_ratio, code) }.into_result()?;
+	Ok(ret)
 }
 
 /// Gray-world white balance algorithm
@@ -378,7 +393,8 @@ pub trait GrayworldWBConst: crate::xphoto::WhiteBalancerConst {
 	/// setSaturationThreshold
 	#[inline]
 	fn get_saturation_threshold(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_GrayworldWB_getSaturationThreshold_const(self.as_raw_GrayworldWB()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_GrayworldWB_getSaturationThreshold_const(self.as_raw_GrayworldWB()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -392,7 +408,8 @@ pub trait GrayworldWB: crate::xphoto::GrayworldWBConst + crate::xphoto::WhiteBal
 	/// setSaturationThreshold getSaturationThreshold
 	#[inline]
 	fn set_saturation_threshold(&mut self, val: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_GrayworldWB_setSaturationThreshold_float(self.as_raw_mut_GrayworldWB(), val) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_GrayworldWB_setSaturationThreshold_float(self.as_raw_mut_GrayworldWB(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -419,7 +436,8 @@ pub trait LearningBasedWBConst: crate::xphoto::WhiteBalancerConst {
 	/// setRangeMaxVal
 	#[inline]
 	fn get_range_max_val(&self) -> Result<i32> {
-		unsafe { sys::cv_xphoto_LearningBasedWB_getRangeMaxVal_const(self.as_raw_LearningBasedWB()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_LearningBasedWB_getRangeMaxVal_const(self.as_raw_LearningBasedWB()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Threshold that is used to determine saturated pixels, i.e. pixels where at least one of the
@@ -428,7 +446,8 @@ pub trait LearningBasedWBConst: crate::xphoto::WhiteBalancerConst {
 	/// setSaturationThreshold
 	#[inline]
 	fn get_saturation_threshold(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_LearningBasedWB_getSaturationThreshold_const(self.as_raw_LearningBasedWB()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_LearningBasedWB_getSaturationThreshold_const(self.as_raw_LearningBasedWB()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Defines the size of one dimension of a three-dimensional RGB histogram that is used internally
@@ -438,7 +457,8 @@ pub trait LearningBasedWBConst: crate::xphoto::WhiteBalancerConst {
 	/// setHistBinNum
 	#[inline]
 	fn get_hist_bin_num(&self) -> Result<i32> {
-		unsafe { sys::cv_xphoto_LearningBasedWB_getHistBinNum_const(self.as_raw_LearningBasedWB()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_LearningBasedWB_getHistBinNum_const(self.as_raw_LearningBasedWB()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -464,7 +484,8 @@ pub trait LearningBasedWB: crate::xphoto::LearningBasedWBConst + crate::xphoto::
 	fn extract_simple_features(&mut self, src: &dyn core::ToInputArray, dst: &mut dyn core::ToOutputArray) -> Result<()> {
 		input_array_arg!(src);
 		output_array_arg!(dst);
-		unsafe { sys::cv_xphoto_LearningBasedWB_extractSimpleFeatures_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_LearningBasedWB(), src.as_raw__InputArray(), dst.as_raw__OutputArray()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_LearningBasedWB_extractSimpleFeatures_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_LearningBasedWB(), src.as_raw__InputArray(), dst.as_raw__OutputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Maximum possible value of the input image (e.g. 255 for 8 bit images,
@@ -473,7 +494,8 @@ pub trait LearningBasedWB: crate::xphoto::LearningBasedWBConst + crate::xphoto::
 	/// setRangeMaxVal getRangeMaxVal
 	#[inline]
 	fn set_range_max_val(&mut self, val: i32) -> Result<()> {
-		unsafe { sys::cv_xphoto_LearningBasedWB_setRangeMaxVal_int(self.as_raw_mut_LearningBasedWB(), val) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_LearningBasedWB_setRangeMaxVal_int(self.as_raw_mut_LearningBasedWB(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Threshold that is used to determine saturated pixels, i.e. pixels where at least one of the
@@ -482,7 +504,8 @@ pub trait LearningBasedWB: crate::xphoto::LearningBasedWBConst + crate::xphoto::
 	/// setSaturationThreshold getSaturationThreshold
 	#[inline]
 	fn set_saturation_threshold(&mut self, val: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_LearningBasedWB_setSaturationThreshold_float(self.as_raw_mut_LearningBasedWB(), val) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_LearningBasedWB_setSaturationThreshold_float(self.as_raw_mut_LearningBasedWB(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Defines the size of one dimension of a three-dimensional RGB histogram that is used internally
@@ -492,7 +515,8 @@ pub trait LearningBasedWB: crate::xphoto::LearningBasedWBConst + crate::xphoto::
 	/// setHistBinNum getHistBinNum
 	#[inline]
 	fn set_hist_bin_num(&mut self, val: i32) -> Result<()> {
-		unsafe { sys::cv_xphoto_LearningBasedWB_setHistBinNum_int(self.as_raw_mut_LearningBasedWB(), val) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_LearningBasedWB_setHistBinNum_int(self.as_raw_mut_LearningBasedWB(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -508,7 +532,8 @@ pub trait SimpleWBConst: crate::xphoto::WhiteBalancerConst {
 	/// setInputMin
 	#[inline]
 	fn get_input_min(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_SimpleWB_getInputMin_const(self.as_raw_SimpleWB()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_getInputMin_const(self.as_raw_SimpleWB()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Input image range maximum value
@@ -516,7 +541,8 @@ pub trait SimpleWBConst: crate::xphoto::WhiteBalancerConst {
 	/// setInputMax
 	#[inline]
 	fn get_input_max(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_SimpleWB_getInputMax_const(self.as_raw_SimpleWB()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_getInputMax_const(self.as_raw_SimpleWB()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Output image range minimum value
@@ -524,7 +550,8 @@ pub trait SimpleWBConst: crate::xphoto::WhiteBalancerConst {
 	/// setOutputMin
 	#[inline]
 	fn get_output_min(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_SimpleWB_getOutputMin_const(self.as_raw_SimpleWB()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_getOutputMin_const(self.as_raw_SimpleWB()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Output image range maximum value
@@ -532,7 +559,8 @@ pub trait SimpleWBConst: crate::xphoto::WhiteBalancerConst {
 	/// setOutputMax
 	#[inline]
 	fn get_output_max(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_SimpleWB_getOutputMax_const(self.as_raw_SimpleWB()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_getOutputMax_const(self.as_raw_SimpleWB()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Percent of top/bottom values to ignore
@@ -540,7 +568,8 @@ pub trait SimpleWBConst: crate::xphoto::WhiteBalancerConst {
 	/// setP
 	#[inline]
 	fn get_p(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_SimpleWB_getP_const(self.as_raw_SimpleWB()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_getP_const(self.as_raw_SimpleWB()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -553,7 +582,8 @@ pub trait SimpleWB: crate::xphoto::SimpleWBConst + crate::xphoto::WhiteBalancer
 	/// setInputMin getInputMin
 	#[inline]
 	fn set_input_min(&mut self, val: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_SimpleWB_setInputMin_float(self.as_raw_mut_SimpleWB(), val) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_setInputMin_float(self.as_raw_mut_SimpleWB(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Input image range maximum value
@@ -561,7 +591,8 @@ pub trait SimpleWB: crate::xphoto::SimpleWBConst + crate::xphoto::WhiteBalancer
 	/// setInputMax getInputMax
 	#[inline]
 	fn set_input_max(&mut self, val: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_SimpleWB_setInputMax_float(self.as_raw_mut_SimpleWB(), val) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_setInputMax_float(self.as_raw_mut_SimpleWB(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Output image range minimum value
@@ -569,7 +600,8 @@ pub trait SimpleWB: crate::xphoto::SimpleWBConst + crate::xphoto::WhiteBalancer
 	/// setOutputMin getOutputMin
 	#[inline]
 	fn set_output_min(&mut self, val: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_SimpleWB_setOutputMin_float(self.as_raw_mut_SimpleWB(), val) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_setOutputMin_float(self.as_raw_mut_SimpleWB(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Output image range maximum value
@@ -577,7 +609,8 @@ pub trait SimpleWB: crate::xphoto::SimpleWBConst + crate::xphoto::WhiteBalancer
 	/// setOutputMax getOutputMax
 	#[inline]
 	fn set_output_max(&mut self, val: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_SimpleWB_setOutputMax_float(self.as_raw_mut_SimpleWB(), val) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_setOutputMax_float(self.as_raw_mut_SimpleWB(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 	/// Percent of top/bottom values to ignore
@@ -585,7 +618,8 @@ pub trait SimpleWB: crate::xphoto::SimpleWBConst + crate::xphoto::WhiteBalancer
 	/// setP getP
 	#[inline]
 	fn set_p(&mut self, val: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_SimpleWB_setP_float(self.as_raw_mut_SimpleWB(), val) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_SimpleWB_setP_float(self.as_raw_mut_SimpleWB(), val) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -603,22 +637,26 @@ pub trait TonemapDurandConst: crate::photo::TonemapConst {
 
 	#[inline]
 	fn get_saturation(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_TonemapDurand_getSaturation_const(self.as_raw_TonemapDurand()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_TonemapDurand_getSaturation_const(self.as_raw_TonemapDurand()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_contrast(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_TonemapDurand_getContrast_const(self.as_raw_TonemapDurand()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_TonemapDurand_getContrast_const(self.as_raw_TonemapDurand()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_sigma_space(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_TonemapDurand_getSigmaSpace_const(self.as_raw_TonemapDurand()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_TonemapDurand_getSigmaSpace_const(self.as_raw_TonemapDurand()) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_sigma_color(&self) -> Result<f32> {
-		unsafe { sys::cv_xphoto_TonemapDurand_getSigmaColor_const(self.as_raw_TonemapDurand()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_TonemapDurand_getSigmaColor_const(self.as_raw_TonemapDurand()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -628,22 +666,26 @@ pub trait TonemapDurand: crate::photo::Tonemap + crate::xphoto::TonemapDurandCon
 
 	#[inline]
 	fn set_saturation(&mut self, saturation: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_TonemapDurand_setSaturation_float(self.as_raw_mut_TonemapDurand(), saturation) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_TonemapDurand_setSaturation_float(self.as_raw_mut_TonemapDurand(), saturation) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_contrast(&mut self, contrast: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_TonemapDurand_setContrast_float(self.as_raw_mut_TonemapDurand(), contrast) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_TonemapDurand_setContrast_float(self.as_raw_mut_TonemapDurand(), contrast) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_sigma_space(&mut self, sigma_space: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_TonemapDurand_setSigmaSpace_float(self.as_raw_mut_TonemapDurand(), sigma_space) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_TonemapDurand_setSigmaSpace_float(self.as_raw_mut_TonemapDurand(), sigma_space) }.into_result()?;
+		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_sigma_color(&mut self, sigma_color: f32) -> Result<()> {
-		unsafe { sys::cv_xphoto_TonemapDurand_setSigmaColor_float(self.as_raw_mut_TonemapDurand(), sigma_color) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_TonemapDurand_setSigmaColor_float(self.as_raw_mut_TonemapDurand(), sigma_color) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
@@ -668,7 +710,8 @@ pub trait WhiteBalancer: core::AlgorithmTrait + crate::xphoto::WhiteBalancerCons
 	fn balance_white(&mut self, src: &dyn core::ToInputArray, dst: &mut dyn core::ToOutputArray) -> Result<()> {
 		input_array_arg!(src);
 		output_array_arg!(dst);
-		unsafe { sys::cv_xphoto_WhiteBalancer_balanceWhite_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_WhiteBalancer(), src.as_raw__InputArray(), dst.as_raw__OutputArray()) }.into_result()
+		let ret = unsafe { sys::cv_xphoto_WhiteBalancer_balanceWhite_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_WhiteBalancer(), src.as_raw__InputArray(), dst.as_raw__OutputArray()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
